package de.hawhamburg.reachability.tools.googleCalendar.json;

import com.google.gdata.data.DateTime;

import de.hawhamburg.lifecycle.data.JsonLPObject;
import de.hawhamburg.reachability.tools.googleCalendar.enumeration.CalendarRequestType;

/**
 * A JSON message which represents a request to the google calendar service.<br><br>
 * 
 * This class represents the structure of the JSON messages which describes a request to the google calendar service. 
 * This message contains detailed informations to specify the request. These messages will be generally sent by sensor
 * agents to sense certain events of the inhabitants.
 * 
 * @author  {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_AUTHOR} 
 * @version {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_VERSION}
 */
public class JsonGoogleCalendarRequest extends JsonLPObject {
    
    /**
     * The type of request as {@link CalendarRequestType}.
     */
    public CalendarRequestType requestType;
    
    /**
     * The maximum amount of requested events, <code>-1</code> is used as a wildcard for all found results.  
     */
    public Integer amount;
    
    /**
     * Optional parameter. If delivered, it defines the start time of the search.
     */
    public DateTime min;
    
    /**
     * Optional parameter. If delivered, it defines the end time of the search.
     */
    public DateTime max;
    
    /**
     * Public default constructor to create instances of this class.
     */
    public JsonGoogleCalendarRequest() { }
}
