package de.hawhamburg.reachability.tools.googleCalendar.json;

import java.util.List;

import de.hawhamburg.lifecycle.data.JsonLPObject;
import de.hawhamburg.reachability.tools.googleCalendar.enumeration.CalendarRequestType;

/**
 * A JSON message which represents a result of the google calendar service.<br><br>
 * 
 * This class represents the structure of the JSON messages which describes a result of the google calendar service. 
 * This message contains informations related to the request message and google calendar events as 
 * {@link JsonGoogleCalendarEvent} if the request was successful. These messages will be generally sent by the
 * {@link de.hawhamburg.reachability.tools.googleCalendar.GoogleCalendarHookService}.
 * 
 * @author  {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_AUTHOR} 
 * @version {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_VERSION}
 */
public class JsonGoogleCalendarResult extends JsonLPObject {
    
    /**
     * The ID of the request as {@link String} to which this message is the result.
     */
    public String requestId;
    
    /**
     * The {@link CalendarRequestType} of the request message.
     */
    public CalendarRequestType requestType;
    
    /**
     * The number of found events.
     */
    public Integer amount;
    
    /**
     * The found events as {@link List} of {@link JsonGoogleCalendarEvent}.
     */
    public List<JsonGoogleCalendarEvent> events;
    
    /**
     * Public default constructor to create instances of this class.
     */
    public JsonGoogleCalendarResult() { }
}
