package de.hawhamburg.reachability.util;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Properties;

import de.hawhamburg.reachability.ProjectInfo;

/**
 * Utility functions related to properties.<br><br>
 * 
 * This utility class provides fancy functions to easily handle {@link Properties}.
 *
 * @author  {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_AUTHOR}
 * @version {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_VERSION}
 */
public final class PropertiesUtil {
     
    /**
     * Prevent instances of this utility class.
     */
    private PropertiesUtil() { }

    /**
     * This static method loads the {@link Properties} from a properties file which path is given as parameter.
     *
     * @param path  The path to the properties file as string.
     * @return      The {@link Properties} object loaded from the given file path or null
     */
    public static Properties getProperties(final String path) {
        File confFile = new File(path);
        if (confFile.exists()) {
            Properties prop = new Properties();
            try {
                prop.load(new FileReader(confFile));
                return prop;
            } catch (FileNotFoundException e) {
                OutputUtil.error("[FileNotFoundException] " + e.getMessage());
            } catch (IOException e) {
                OutputUtil.error("[IOException] "           + e.getMessage());
            }
        } else {
            OutputUtil.endSystemWithError("The required file '" + path + "' doesn't exist!");
        }
        return null;
    }
    
    /**
     * Stores a {@link Properties} object to a properties file defined by a given path including an auto-creation 
     * comment at the beginning of the file. 
     * 
     * @param props The {@link Properties} object which shall be persisted.
     * @param path  The path to the properties file to which the properties shall be stored.
     */
    public static void save(final Properties props,
                            final String path) {
        try {
            props.store(new FileWriter(new File(path)),
                        " Automated stored by " + PropertiesUtil.class.getName()
                        + "\n# - Author:    " + ProjectInfo.REACHABILITY_AGENT_AUTHOR
                        + "\n# - Institute: " + ProjectInfo.REACHABILITY_AGENT_INSTITUE
                        + "\n# - Version:   " + ProjectInfo.REACHABILITY_AGENT_VERSION);
        } catch (IOException e) {
            OutputUtil.error("[IOException] " + e.getMessage());
        }
    }
}
